<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="30"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Kjør programmer ved å angi en filsti som argument for å laste inn filen.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="31"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>Å dra og slippe filen i vinduet støttes også.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Ingen av operasjonene i dette programmet vil endre bildet som det er lagret.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Context menu option explanation:</source>
        <translation>Forklaring av alternativer i bindeleddsmeny:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="40"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Få vinduet til å alltid ligge over andre vinduer.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="43"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Unngå lukking av vinduet ved feiltagelser (f.eks. ved dobbeltklikking av vinduet)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="54"/>
        <source>Version: %1</source>
        <translation>Versjon: %1</translation>
    </message>
    <message>
        <source>Copyright (c) 2020 %1</source>
        <translation type="vanished">Opphavsrett © 2020 %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="60"/>
        <source>Logo designed by %1</source>
        <translation>Logo designet av %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Bygd med Qt %1 (%2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Source code</source>
        <translation>Kildekode</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Contributors</source>
        <translation>Bidragsytere</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="75"/>
        <source>List of contributors on GitHub</source>
        <translation>Liste over bidragsytere på GitHub</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Takk til alle som har bidratt til prosjektet.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="80"/>
        <source>Translators</source>
        <translation>Oversettere</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>Takk til følgende dugnadsoversettere.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="125"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation type="unfinished">%1 er bygd med følgende friprog-bibliotek:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="149"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp;Spesiell takk til</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="151"/>
        <source>&amp;Third-party Libraries</source>
        <translation>&amp;Tredjepartslisenser</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>Your Rights</source>
        <translation>Dine rettigheter</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="46"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="57"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation type="unfinished">Opphavsrett © %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="89"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 er MIT-lisensiert.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="90"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Lisensen gir den en rekke friheter:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="91"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>Du kan bruke %1 som du vil</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="92"/>
        <source>You are free to distribute %1</source>
        <translation>Du kan dele %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>You can study how %1 works and change it</source>
        <translation>Du kan se kildekoden til %1 og endre den</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>You can distribute changed versions of %1</source>
        <translation>Du kan distribuere endrede versjoner av %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>MIT-lisensen garanterer deg disse frihetene.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="124"/>
        <source>Third-party Libraries used by %1</source>
        <translation>Tredjepartsbibliotek brukt av %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="147"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="148"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="150"/>
        <source>&amp;License</source>
        <translation>&amp;Lisens</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../graphicsscene.cpp" line="89"/>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Drag image here</source>
        <translation>Dra bilde hit</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="351"/>
        <source>File url list is empty</source>
        <translation>Listen over filnettadresser er tom</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="52"/>
        <source>File is not a valid image</source>
        <translation>Filen er ikke et gyldig bilde</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="57"/>
        <location filename="../graphicsview.cpp" line="62"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>Ugyldig bildedata, eller for tiden ustøttet</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="359"/>
        <source>Image data is invalid</source>
        <translation>Ugyldig bildedata</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="366"/>
        <source>Not supported mimedata: %1</source>
        <translation>Ustøttet MIME-data: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>File url list is empty</source>
        <translation>Listen over filnettadresser er ugyldig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="737"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="742"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Copy P&amp;ixmap</source>
        <translation type="unfinished">Kopier p&amp;ixmap</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Copy &amp;File Path</source>
        <translation>Kopier %filsti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="39"/>
        <location filename="../actionmanager.cpp" line="110"/>
        <source>Stay on top</source>
        <translation>Behold øverst</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Protected mode</source>
        <translation>Beskyttet modus</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <location filename="../actionmanager.cpp" line="112"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>Zoom in</source>
        <translation>Førstørr</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="96"/>
        <source>Zoom out</source>
        <translation>Forminsk</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Speilvend &amp;horisontalt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>&amp;Paste</source>
        <translation>&amp;Lim inn</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Toggle Checkerboard</source>
        <translation type="unfinished">Skru av/på rutemønster</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Open...</source>
        <translation>&amp;Åpne …</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Actual size</source>
        <translation>Faktisk størrelse</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Toggle maximize</source>
        <translation type="unfinished">Veksle maksimering</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Rotate right</source>
        <translation>Roter til høyre</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Previous image</source>
        <translation>Forrige bilde</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Next image</source>
        <translation>Neste bilde</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Configure...</source>
        <translation>Sett opp …</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Vis i filutforsker</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="123"/>
        <source>Show in directory</source>
        <translation type="unfinished">Vis i mappe</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="126"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>Bilde-metadata</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="41"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Opprinnelse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Bilde</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="33"/>
        <source>%1 File</source>
        <translation>%1-fil</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="40"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Avansert bilde</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="50"/>
        <source>Dimensions</source>
        <translation>Dimensjoner</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Aspect ratio</source>
        <translation>Sideforhold</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="56"/>
        <source>Frame count</source>
        <translation type="unfinished">Rammeantall</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="60"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Item type</source>
        <translation>Elementstype</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Folder path</source>
        <translation>Mappesti</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Date created</source>
        <translation>Dato opprettet</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date modified</source>
        <translation>Dato endret</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="77"/>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Subject</source>
        <translation>Emne</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Rating</source>
        <translation>Vurdering</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Tags</source>
        <translation>Etiketter</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Comments</source>
        <translation>Kommentarer</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="88"/>
        <source>Authors</source>
        <translation>Utviklere</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Date taken</source>
        <translation>Dato tatt</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="96"/>
        <source>Program name</source>
        <translation>Programnavn</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Copyright</source>
        <translation>Opphavsrett</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="101"/>
        <source>Horizontal resolution</source>
        <translation>Vannrett oppløsning</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Vertical resolution</source>
        <translation>Loddrett oppløsning</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Resolution unit</source>
        <translation>Oppløsningsenhet</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Colour representation</source>
        <translation>Fargerepresentasjon</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="110"/>
        <source>Camera maker</source>
        <translation>Kamerafabrikat</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>F-stop</source>
        <translation>Blenderåpning</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>Exposure time</source>
        <translation>Eksponeringstid</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>ISO speed</source>
        <translation>ISO-hastighet</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>Exposure bias</source>
        <translation type="unfinished">Eksponeringskorrigering</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Focal length</source>
        <translation>Brennvidde</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Max aperture</source>
        <translation type="unfinished">Maks. blenderåpning</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Metering mode</source>
        <translation type="unfinished">Målingsmodus</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Subject distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Flash mode</source>
        <translation>Blitz-modus</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>35mm focal length</source>
        <translation type="unfinished">35 mm-brennvidde</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="135"/>
        <source>Lens model</source>
        <translation>Linsemodell</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Brightness</source>
        <translation>Lysstyrke</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Exposure program</source>
        <translation type="unfinished">Eksponeringsprogram</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Saturation</source>
        <translation>Metning</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Sharpness</source>
        <translation>Skarphet</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>White balance</source>
        <translation>Hvitbalanse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>Digital zoom</source>
        <translation>Digital forstørrelse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>EXIF version</source>
        <translation>EXIF-versjon</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="154"/>
        <source>Latitude reference</source>
        <translation>Breddegradsreferanse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude</source>
        <translation>Breddegrad</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Longitude reference</source>
        <translation>Lengdegradsreferanse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude</source>
        <translation>Lengdegrad</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Altitude reference</source>
        <translation>Høydereferanse</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="174"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="192"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Property</source>
        <translation>Egenskap</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Value</source>
        <translation>Verdi</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="22"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="27"/>
        <source>Do nothing</source>
        <translation>Ikke gjør noe</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="28"/>
        <source>Close the window</source>
        <translation>Lukk vinduet</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <source>Toggle maximize</source>
        <translation>Veksle maksimering</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Zoom in and out</source>
        <translation>Zoom inn og ut</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>View next or previous item</source>
        <translation>Vis neste eller forrige element</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Auto size</source>
        <translation type="unfinished">Automatisk størrelse</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Maximized</source>
        <translation>Maksimert</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Stay on top when start-up</source>
        <translation>Behold i forgrunnen ved oppstart</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Double-click behavior</source>
        <translation>Dobbeltklikksoppførsel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Mouse wheel behavior</source>
        <translation>Musehjulsoppførsel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="72"/>
        <source>Default window size</source>
        <translation>Forvalgt vindusstørrelse</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="73"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>Pineapple Pictures</source>
        <translation>Pineapple Pictures</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>File list.</source>
        <translation>Filliste.</translation>
    </message>
</context>
</TS>
